OC.L10N.register(
    "lib",
    {
    "Unknown filetype" : "غیر معرروف قسم کی فائل",
    "Invalid image" : "غلط تصویر",
    "today" : "آج",
    "yesterday" : "کل",
    "last month" : "پچھلے مہنیے",
    "last year" : "پچھلے سال",
    "seconds ago" : "سیکنڈز پہلے",
    "Apps" : "ایپز",
    "Help" : "مدد",
    "Personal" : "ذاتی",
    "Users" : "یوزرز",
    "Admin" : "ایڈمن",
    "web services under your control" : "آپ کے اختیار میں ویب سروسیز"
},
"nplurals=2; plural=(n != 1);");
